@@ -11,7 +11,7 @@ from scaleup.script_utils import *
 #   targetType of 1 is Excel 
 #   targetType of 2 is Reaction Lab
 
-def create_script_parameters(name : str , file_name : str, options : str = '', dataSheets = None):
+def create_script_parameters(name : str , file_name : str, options : str = '', dataSheets = None, injected_headers = None):
 	"""Creates a script parameters class
 
 	:param name: Name of the automation job
@@ -22,6 +22,8 @@ def create_script_parameters(name : str , file_name : str, options : str = '', d
 	:type options: str, optional
 	:param dataSheets: Custom Datasheets, defaults to None
 	:type dataSheets: [type], optional
+	:param injected_headers: Injected parameters - not from scenarios sheet, defaults to None
+	:type injected_headers: [type], optional
 	:raises ValueError: If the model is not of a supported type (must be .xls? or .rxm)
 	:return: COM object of script parameters
 	:rtype: COM object
@@ -39,10 +41,12 @@ def create_script_parameters(name : str , file_name : str, options : str = '', d
 	parameters.Options = options
 	if(dataSheets != None):
 		set_datasheets(parameters, dataSheets)
+	if(injected_headers != None):
+		set_injected_headers(parameters, injected_headers)
 	return parameters
 
 
-def create_simulation_step(scenarios = [], writeProfiles : bool = False, returnProfiles : bool = False) -> pythoncom.VT_DISPATCH:
+def create_simulation_step(scenarios = [], writeProfiles : bool = False, returnProfiles : bool = False, calc_wssq : bool = False) -> pythoncom.VT_DISPATCH:
 	"""Creates a simulation step
 
 	:param scenarios: The scenarios to be run, If empty, all are run, defaults to []
@@ -51,6 +55,8 @@ def create_simulation_step(scenarios = [], writeProfiles : bool = False, returnP
 	:type writeProfiles: bool, optional
 	:param returnProfiles: return the profiles as well as the endpoints, defaults to False
 	:type returnProfiles: bool, optional
+	:param calc_wssq: calculate wssq, defaults to False
+	:type calc_wssq: bool, optional
 	:return: Script step
 	:rtype: COM Object
 	"""
@@ -62,6 +68,7 @@ def create_simulation_step(scenarios = [], writeProfiles : bool = False, returnP
 	stepParameters.RunType = 1 if len(scenarios) == 0 else 3
 	stepParameters.writeProfiles = writeProfiles
 	stepParameters.ReturnProfiles = returnProfiles
+	stepParameters.CalcWSSQ = calc_wssq
 	step.StepParameters = stepParameters
 	return step
 
@@ -140,10 +147,14 @@ def set_datasheets(script, datasheets):
 	datasheets_variant = VARIANT(pythoncom.VT_ARRAY | pythoncom.VT_VARIANT, datasheets)
 	script.DataSheets = datasheets_variant
 
+def set_injected_headers(script, headers):
+	headers_variant = VARIANT(pythoncom.VT_ARRAY | pythoncom.VT_VARIANT, headers)
+	script.InjectedHeaders = headers_variant	
+
 #=================================================================================================
 # ScriptType generated from filename
 	
-def run_script(file_name : str, script_name : str, steps, options : str = '', dataSheets = None) -> pythoncom.VT_DISPATCH:
+def run_script(file_name : str, script_name : str, steps, options : str = '', dataSheets = None, injected_headers = None) -> pythoncom.VT_DISPATCH:
 	"""Runs a script
 
 	:param file_name: The file name for the model
@@ -160,7 +171,7 @@ def run_script(file_name : str, script_name : str, steps, options : str = '', da
 	:rtype: COM Object
 	"""
 
-	parameters = create_script_parameters(script_name, file_name, options, dataSheets)
+	parameters = create_script_parameters(script_name, file_name, options, dataSheets, injected_headers)
 	parameters.Steps = steps
 
 	runner = create_model_automate_w32()
